import url from "./url.js"
const install = (Vue, vm) => {
	Vue.prototype.$u.http.setConfig({
		baseUrl: url, // 请求的本域名
		loadingText: '加载中...',
		loadingTime: 800,
		showLoading: true, // 是否显示请求中的loading
		loadingMask: true, // 展示loading的时候，是否给一个透明的蒙层，防止触摸穿透
		originalData: true, // 是否在拦截器中返回服务端的原始数据
		// 配置请求头信息
		header: {
			'content-type': 'application/json;charset=UTF-8',
			'version': 'v1'
		},
	});
	// 请求拦截部分，如配置，每次请求前都会执行
	Vue.prototype.$u.http.interceptor.request = (config) => {
		// 引用token
		// 方式一，存放在vuex的token，假设使用了uView封装的vuex方式
		// 见：https://uviewui.com/components/globalVariable.html
		// config.header.token = vm.token;

		// 方式二，如果没有使用uView封装的vuex方法，那么需要使用$store.state获取
		// config.header.token = vm.$store.state.token;

		// 方式三，如果token放在了globalData，通过getApp().globalData获取
		// config.header.token = getApp().globalData.username;

		// 方式四，如果token放在了Storage本地存储中，拦截是每次请求都执行的
		// 所以哪怕您重新登录修改了Storage，下一次的请求将会是最新值
		const token = uni.getStorageSync('token');
		config.header.Authorization = token;

		// 可以对某个url进行特别处理，此url参数为this.$u.get(url)中的url值
		// if(config.url == '/user/login') config.header.noToken = true;
		// 最后需要将config进行return
		return config;
		// 如果return一个false值，则会取消本次请求
		// if(config.url == '/user/rest') return false; // 取消某次请求
	}
	// 响应拦截，如配置，每次请求结束都会执行本方法
	Vue.prototype.$u.http.interceptor.response = (res) => {
		if (res.statusCode == 200) {
			// res为服务端返回值，可能有code，result等字段
			// 这里对res.result进行返回，将会在this.$u.post(url).then(res => {})的then回调中的res的到
			// 如果配置了originalData为true，请留意这里的返回值
			return res.data;
		} else {
			// 假设201为token失效，这里跳转登录
			if (res.statusCode == 500) {
				// var html = res.data
				// var start = html.indexOf('<h1>')
				// var end = html.indexOf('</h1>')
				// var title = html.substring(start + 4, end)

				// var start1 = html.indexOf('</abbr> in <a class="toggle" title=')
				// var end1 = html.indexOf('</a></h2>')
				// var title1 = html.substring(start1 + 35, end1)

				// uni.showModal({
				// 	title: `网络错误：${res.statusCode}`,
				// 	content: `位置：${title1}\r\n 标题：${title}`
				// })
			} else {
				uni.showModal({
					content: `未知错误：${res.statusCode}`
				})
			}
			return false;
		}
	}
}

export default {
	install
}
